C.R.A.SSH 
=========
C.R.A.SSH (*crassh*) stands for *Cisco Remote Automation via SSH*, it is a python script for automating commands on Cisco devices.

|build-status| |docs|

Crassh can be used in two ways: 

* a stand alone script that users (*Network Admins*) can run to perform actions on Cisco devices
* a module developers can import and leverage in their own scripts

The  **documentation is available here:** http://crassh.readthedocs.org

My `personal blog`_ contains a `tutorial here`_ on how to use crassh in standalone mode and an `initial example`_ on how to use the crassh module. Future `news about crassh can be found here`_.




Disclaimer
^^^^^^^^^^

The word *Cisco* is used as a description because this script should work with any Cisco IOS device. Cisco is a registered trademark of Cisco Systems Inc; this script is not associated, endorsed, supported or affiliated in any way with Cisco and none of these are implied.

.. Links

.. _`personal blog`: http://www.linickx.com
.. _`tutorial here`: http://www.linickx.com/3980/automating-cisco-commands-with-c-r-a-ssh
.. _`initial example`: http://linickx.com/pip-install-crassh
.. _`news about crassh can be found here`: http://www.linickx.com/tag/crassh

.. |build-status| image:: https://travis-ci.org/linickx/crassh.svg?branch=master
   :target: https://travis-ci.org/linickx/crassh
   :alt: Travis CI: continuous integration status
.. |docs| image:: https://readthedocs.org/projects/crassh/badge/?version=latest
   :target: http://crassh.readthedocs.org/en/latest/?badge=latest
   :alt: Documentation Status
